Title: [commits] (heikki) [11154] Add Intel Mac to the list of builds copied to continuous/qa.
Revision
11154
Author
heikki
Date
2006-07-13 15:35:51 -0700 (Thu, 13 Jul 2006)

Log Message

Add Intel Mac to the list of builds copied to continuous/qa.

Modified Paths

Diff

Modified: trunk/hardhat/qa/createlatest.py (11153 => 11154)

--- trunk/hardhat/qa/createlatest.py	2006-07-13 22:08:23 UTC (rev 11153)
+++ trunk/hardhat/qa/createlatest.py	2006-07-13 22:35:51 UTC (rev 11154)
@@ -22,7 +22,7 @@
     #                            
     # source tree:
     #    /home/builder/www/chandler/continuous
     #        + ( osx | win | linux )
     #            + YYYYMMDDHHMMSS 
     #
     # target tree:
@@ -31,6 +31,7 @@
     # each build will be present in qa named as:
     #                   
     #     Chandler_osx.dmg
+    #     Chandler_iosx.dmg
     #     Chandler_win.exe
     #     Chandler_win.zip
     #     Chandler_linux.i386.rpm
@@ -40,7 +41,7 @@
 import os, glob, string
 
 workingDirectory = '/home/builder/www/docs/chandler/continuous'
-platforms        = ['osx', 'win', 'linux']
+platforms        = ['osx', 'win', 'linux', 'iosx']
         
 def main():
     os.chdir(workingDirectory)
@@ -22,7 +22,7 @@
     # source tree:
     #    /home/builder/www/chandler/continuous
-    #        + ( osx | win | linux )
+    #        + ( osx | win | linux | iosx)
     #            + YYYYMMDDHHMMSS 
     #




_______________________________________________
Commits mailing list
[email protected]
http://lists.osafoundation.org/mailman/listinfo/commits

Reply via email to